import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import Link from "next/link";
import "../globals.css";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING - Online Voting System",
  description: "Secure online voting system for SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING club members",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="de">
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        {/*<header className="ssvc-header">
          <div className="ssvc-logo-container">
            <div className="w-24 h-24 relative">
              <div className="absolute inset-0 bg-[#0057a6] flex items-center justify-center text-white font-bold" >
                <Image 
                  src="/ssvc-logo.svg" 
                  alt="SSVC Logo" 
                  width={92} 
                  height={48} 
                  priority
                />
              </div>
            </div>
            <div className="ssvc-logo-text">
              <div className="text-sm font-bold">SCHAFWASCHENER SEGELVEREIN</div>
              <div className="text-sm font-bold">CHIEMSEE E.V.</div>
              <div className="text-sm font-bold">RIMSTING</div>
            </div>
          </div>
        </header>*/}
        <nav className="ssvc-nav">
          <Link href="/">HOME</Link>
          <Link href="/admin">ADMIN</Link>
        </nav>
        <main>
          {children}
        </main>
        <footer className="ssvc-footer border-t border-gray-200 text-gray-700 py-3 mt-8">
          <div className="container mx-auto px-4">
            <div className="flex flex-col md:flex-row justify-between items-center">
              <div className="mb-4 md:mb-0">
                <p className="text-center md:text-left">© {new Date().getFullYear()} SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING. Alle Rechte vorbehalten.</p>
              </div>
              <div className="text-center md:text-right">
                <p className="whitespace-nowrap">Erstellt von <a href="https://jeanavril.com" target="_blank" rel="noopener noreferrer" className="font-medium text-gray-800 hover:text-blue-600 hover:underline transition-colors no-underline">Jean Jacques Avril</a></p>
              </div>
            </div>
          </div>
        </footer>
      </body>
    </html>
  );
}
